@@ -38,9 +38,21 @@ class Tools:
                 new_headers.update({'Authorization': f'Bearer {new_access_token}'})
                 kwargs.update({'headers': new_headers})
                 continue
+            elif response.status_code != 200:
+                raise Exception(response.json())
             else:
                 return response
 
+    def rename_channel(self, name, channel_url, session_key):
+        data = json.dumps({
+            # 'cover_url': '',
+            'name': name,
+            # 'data': ''
+        })
+        uri = f"{SB_PROXY_CHATMEDIA}/v3/group_channels/{channel_url}"
+        response = self._handled_req(method='PUT', uri=uri, data=data, headers={'Session-Key': session_key})
+        return Channel.from_dict(response.json())
+
     def delete_message(self, channel_url, msg_id, session_key):
         uri = f"{SB_PROXY_CHATMEDIA}/v3/group_channels/{channel_url}/messages/{msg_id}"
         self._handled_req(method='DELETE', uri=uri, headers={'Session-Key': session_key})
@@ -92,7 +104,7 @@ class Tools:
         }
         url = f'{SB_PROXY_CHATMEDIA}/v3/users/{self._reddit_auth.user_id}/my_group_channels'
         response = self._handled_req(method='GET', uri=url, headers={'Session-Key': session_key}, params=params)
-        return [Channel.from_dict(channel, infer_missing=True) for channel in response.json()['channels']]
+        return [Channel.from_dict(channel) for channel in response.json()['channels']]
 
     def leave_chat(self, channel_url, session_key):
         data = json.dumps({
@@ -113,7 +125,7 @@ class Tools:
         response = self._handled_req(method='POST', uri=url,
                                      headers={'Authorization': f'Bearer {self._reddit_auth.api_token}'},
                                      data=data)
-        return Channel.from_json(response.text, infer_missing=True)
+        return Channel.from_dict(response.json())
 
     def hide_chat(self, user_id, channel_url, hide_previous_messages, allow_auto_unhide, session_key):
         data = json.dumps({
@@ -141,4 +153,4 @@ class Tools:
 
         response = self._handled_req(method='GET', uri=f'{SB_PROXY_CHATMEDIA}/v3/group_channels/{channel_url}/messages',
                                      headers={'Session-Key': session_key}, params=params)
-        return [Message.from_dict(msg, infer_missing=True) for msg in response.json()['messages']]
+        return [Message.from_dict(msg) for msg in response.json()['messages']]
